import json
import time
import requests
class Baron_bot():
    def send_msg(self,Token,ID,S):
        name=['الله' , 'الرحمن' , 'الرحيم' , 'الملك' , 'القدوس' , 'السلام' , 'المؤمن' , 'المهيمن' , 'العزيز' , 'الجبار' , 'المتكبر' , 'الخالق' ,'البارئ' , 'المصور' , 'الغفار' , 'القهار' , 'الوهاب' , 'الرزاق' , 'الفتاح' , 'العليم' , 'القابض' , 'الباسط' , 'الخافض' , 'الرافع' , 'المعز' , 'المذل' , 'السميع' , 'البصير' , 'الحكم' , 'العدل' , 'اللطيف' , 'الخبير' , 'الحليم' , 'العظيم' , 'الغفور' , 'الشكور' , 'العلي' , 'الكبير' , 'الحفيظ' , 'المقيت' , 'الحسيب' , 'الجليل' , 'الكريم' , 'الرقيب' , 'المجيب' , 'الواسع' , 'الحكيم' , 'الودود' , 'المجيد' , 'الباعث' , 'الشهيد' , 'الحق' , 'الوكيل' , 'القوي' , 'المتين' , 'الولي' , 'الحميد' , 'المحصي' , 'المبدئ' , 'المعيد' , 'المحيي' , 'المميت' , 'الحي' , 'القيوم' , 'الواجد' , 'الماجد' , 'الواحد' , 'الأحد' , 'الصمد' , 'القادر' , 'المقتدر' , 'المقدم' , 'المؤخر' , 'الأول' , 'الآخر' , 'الظاهر' , 'الباطن' , 'الوالي' , 'المتعالي' , 'البر' , 'التواب' , 'المنتقم' , 'العفو' , 'الرءوف' , 'مالك الملك' , 'ذو الجلال والإكرام' , 'المقسط' , 'الجامع' ,'الغني' , 'المغني' , 'المانع' , 'الضار' , 'النافع' , 'النور' , 'الهادي' , 'البديع' , 'الباقي' , 'الوارث' , 'الرشيد' , 'الصبور' ]
        for n in name:
            start_msg = requests.post(f"https://api.telegram.org/bot{Token}/sendMessage?chat_id={ID}&text= {n}").json()
            time.sleep(S)
        

#"الله , الرحمن , الرحيم , الملك , القدوس , السلام , المؤمن , المهيمن , العزيز , الجبار , المتكبر , الخالق ,البارئ , المصور , الغفار , القهار , الوهاب , الرزاق , الفتاح , العليم , القابض , الباسط , الخافض , الرافع , المعز , المذل , السميع , البصير , الحكم , العدل , اللطيف , الخبير , الحليم , العظيم , الغفور , الشكور , العلي , الكبير , الحفيظ , المقيت , الحسيب , الجليل , الكريم , الرقيب , المجيب , الواسع , الحكيم , الودود , المجيد , الباعث , الشهيد , الحق , الوكيل , القوي , المتين , الولي , الحميد , المحصي , المبدئ , المعيد , المحيي , المميت , الحي , القيوم , الواجد , الماجد , الواحد , الأحد , الصمد , القادر , المقتدر , المقدم , المؤخر , الأول , الآخر , الظاهر , الباطن , الوالي , المتعالي , البر , التواب , المنتقم , العفو , الرءوف , مالك الملك , ذو الجلال والإكرام , المقسط , الجامع ,الغني , المغني , المانع , الضار , النافع , النور , الهادي , البديع , الباقي , الوارث , الرشيد , الصبور "